@@ -156,11 +156,11 @@ crawl_params_t* crawl_init(int argc, char** argv)
   return crawl_alloc(argc, argv, long_options);
 }
 
-#ifdef HAVE_WORDLIST_H
+#ifdef HAVE_MIFLUZ_H
 extern "C" {
 void* hooksmifluz_init();
 }
-#endif /* HAVE_WORDLIST_H */
+#endif /* HAVE_MIFLUZ_H */
 
 crawl_params_t* crawl_alloc(int argc, char** argv, struct option options[])
 {
@@ -291,17 +291,17 @@ crawl_params_t* crawl_alloc(int argc, char** argv, struct option options[])
   params->robots->base = params->base;
   if(params->candidate_limit <= 0)
     params->candidate_limit = CRAWL_PARAMS_CANDIDATE_LIMIT;
-#ifdef HAVE_WORDLIST_H
+#ifdef HAVE_MIFLUZ_H
   if(!params->no_hook) {
     params->hook = (WebbaseHook*)hooksmifluz_init();
     params->hook->Parse(argc, argv);
     params->hook->Init(params->base);
   } else {
-#endif /* HAVE_WORDLIST_H */
+#endif /* HAVE_MIFLUZ_H */
     params->hook = new WebbaseHook();
-#ifdef HAVE_WORDLIST_H
+#ifdef HAVE_MIFLUZ_H
   }
-#endif /* HAVE_WORDLIST_H */
+#endif /* HAVE_MIFLUZ_H */
 
   return params;
 }
