@@ -21,7 +21,7 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#ifdef HAVE_WORDLIST_H
+#ifdef HAVE_MIFLUZ_H
 
 #include <stdio.h>
 #include <string.h>
@@ -29,10 +29,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <WordList.h>
-#include <WordContext.h>
-#include <Configuration.h>
-
 #include <strshift.h>
 #include <rm.h>
 #include <salloc.h>
@@ -370,4 +366,4 @@ int WebbaseHookMifluz::Close()
   return 1;
 }
 
-#endif /* HAVE_WORDLIST_H */
+#endif /* HAVE_MIFLUZ_H */
