@@ -19,6 +19,14 @@
 #ifndef _mkdirp_h
 #define _mkdirp_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void mkdirp(char* dirname, int dirname_length);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* mkdirp_h */
